==> mediatex-0.4.tar.gz: mediatex-0.4/src/parser/confFile.tab.h <==
/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
# define YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef CONF_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define CONF_DEBUG 1
#  else
#   define CONF_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define CONF_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined CONF_DEBUG */
#if CONF_DEBUG
extern int conf_debug;
#endif

/* Token type.  */
#ifndef CONF_TOKENTYPE
# define CONF_TOKENTYPE
  enum conf_tokentype
  {
    confERROR = 258,
    confHOST = 259,
    confNETWORKS = 260,
    confGATEWAYS = 261,
    confMDTXPORT = 262,
    confSSHPORT = 263,
    confWWWPORT = 264,
    confCACHESIZE = 265,
    confCACHETTL = 266,
    confQUERYTTL = 267,
    confCHECKTTL = 268,
    confFILETTL = 269,
    confSUPPTTL = 270,
    confMAXSCORE = 271,
    confBADSCORE = 272,
    confPOWSUPP = 273,
    confFACTSUPP = 274,
    confCOLL = 275,
    confCOMMENT = 276,
    confSHARE = 277,
    confLOCALHOST = 278,
    confCOMMA = 279,
    confDOT = 280,
    confCOLON = 281,
    confAROBASE = 282,
    confMINUS = 283,
    confENDBLOCK = 284,
    confSTRING = 285,
    confNUMBER = 286,
    confSCORE = 287,
    confSIZE = 288,
    confTIME = 289
  };
#endif
/* Tokens.  */
#define confERROR 258
#define confHOST 259
#define confNETWORKS 260
#define confGATEWAYS 261
#define confMDTXPORT 262
#define confSSHPORT 263
#define confWWWPORT 264
#define confCACHESIZE 265
#define confCACHETTL 266
#define confQUERYTTL 267
#define confCHECKTTL 268
#define confFILETTL 269
#define confSUPPTTL 270
#define confMAXSCORE 271
#define confBADSCORE 272
#define confPOWSUPP 273
#define confFACTSUPP 274
#define confCOLL 275
#define confCOMMENT 276
#define confSHARE 277
#define confLOCALHOST 278
#define confCOMMA 279
#define confDOT 280
#define confCOLON 281
#define confAROBASE 282
#define confMINUS 283
#define confENDBLOCK 284
#define confSTRING 285
#define confNUMBER 286
#define confSCORE 287
#define confSIZE 288
#define confTIME 289

/* Value type.  */
#if ! defined CONF_STYPE && ! defined CONF_STYPE_IS_DECLARED
typedef union CONF_STYPE CONF_STYPE;
union CONF_STYPE
{
#line 61 "parser/confFile.y" /* yacc.c:1909  */

  char          string[MAX_SIZE_STRING+1];
  unsigned int  number;
  float         score;
  off_t         size;
  time_t        time;

#line 138 "parser/confFile.tab.h" /* yacc.c:1909  */
};
# define CONF_STYPE_IS_TRIVIAL 1
# define CONF_STYPE_IS_DECLARED 1
#endif



int conf_parse (yyscan_t yyscanner, Collection* coll);
/* "%code provides" blocks.  */
#line 27 "parser/confFile.y" /* yacc.c:1909  */

/*=======================================================================
 * Version: this file is generated by BISON using confFile.y
 * Project: MediaTeX
 * Module : conf parser
 *
 * configuation file parser

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE CONF_STYPE

#line 176 "parser/confFile.tab.h" /* yacc.c:1909  */

#endif /* !YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED  */

==> mediatex-0.5.tar.gz: mediatex-0.5/src/parser/confFile.tab.h <==
/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
# define YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef CONF_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define CONF_DEBUG 1
#  else
#   define CONF_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define CONF_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined CONF_DEBUG */
#if CONF_DEBUG
extern int conf_debug;
#endif

/* Token type.  */
#ifndef CONF_TOKENTYPE
# define CONF_TOKENTYPE
  enum conf_tokentype
  {
    confERROR = 258,
    confHOST = 259,
    confNETWORKS = 260,
    confGATEWAYS = 261,
    confMDTXPORT = 262,
    confSSHPORT = 263,
    confHTTPPORT = 264,
    confHTTPSPORT = 265,
    confCACHESIZE = 266,
    confCACHETTL = 267,
    confQUERYTTL = 268,
    confCHECKTTL = 269,
    confFILETTL = 270,
    confSUPPTTL = 271,
    confMAXSCORE = 272,
    confBADSCORE = 273,
    confPOWSUPP = 274,
    confFACTSUPP = 275,
    confCOLL = 276,
    confCOMMENT = 277,
    confSHARE = 278,
    confLOCALHOST = 279,
    confCOMMA = 280,
    confDOT = 281,
    confCOLON = 282,
    confAROBASE = 283,
    confMINUS = 284,
    confENDBLOCK = 285,
    confSTRING = 286,
    confNUMBER = 287,
    confSCORE = 288,
    confSIZE = 289,
    confTIME = 290
  };
#endif
/* Tokens.  */
#define confERROR 258
#define confHOST 259
#define confNETWORKS 260
#define confGATEWAYS 261
#define confMDTXPORT 262
#define confSSHPORT 263
#define confHTTPPORT 264
#define confHTTPSPORT 265
#define confCACHESIZE 266
#define confCACHETTL 267
#define confQUERYTTL 268
#define confCHECKTTL 269
#define confFILETTL 270
#define confSUPPTTL 271
#define confMAXSCORE 272
#define confBADSCORE 273
#define confPOWSUPP 274
#define confFACTSUPP 275
#define confCOLL 276
#define confCOMMENT 277
#define confSHARE 278
#define confLOCALHOST 279
#define confCOMMA 280
#define confDOT 281
#define confCOLON 282
#define confAROBASE 283
#define confMINUS 284
#define confENDBLOCK 285
#define confSTRING 286
#define confNUMBER 287
#define confSCORE 288
#define confSIZE 289
#define confTIME 290

/* Value type.  */
#if ! defined CONF_STYPE && ! defined CONF_STYPE_IS_DECLARED
typedef union CONF_STYPE CONF_STYPE;
union CONF_STYPE
{
#line 60 "parser/confFile.y" /* yacc.c:1909  */

  char          string[MAX_SIZE_STRING+1];
  unsigned int  number;
  float         score;
  off_t         size;
  time_t        time;

#line 140 "parser/confFile.tab.h" /* yacc.c:1909  */
};
# define CONF_STYPE_IS_TRIVIAL 1
# define CONF_STYPE_IS_DECLARED 1
#endif



int conf_parse (yyscan_t yyscanner, Collection* coll);
/* "%code provides" blocks.  */
#line 26 "parser/confFile.y" /* yacc.c:1909  */

/*=======================================================================
 * Version: this file is generated by BISON using confFile.y
 * Project: MediaTeX
 * Module : conf parser
 *
 * configuation file parser

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 2016 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE CONF_STYPE

#line 178 "parser/confFile.tab.h" /* yacc.c:1909  */

#endif /* !YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED  */
